Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(170)

Unified Diff: src/globals.h

Issue 2506283003: [Interpreter] Collect NumberOrOddball feedback in CompareOps. (Closed)
Patch Set: Rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/interpreter/interpreter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/globals.h
diff --git a/src/globals.h b/src/globals.h
index 4cecb2f03cc024ede624fa4744c02111aa41b7a5..275ec5c522c7bcaf2a081825a553a9982d3d80fc 100644
--- a/src/globals.h
+++ b/src/globals.h
@@ -1241,8 +1241,8 @@ class BinaryOperationFeedback {
// Type feedback is encoded in such a way that, we can combine the feedback
// at different points by performing an 'OR' operation. Type feedback moves
// to a more generic type when we combine feedback.
// kSignedSmall -> kNumber -> kAny
// kString -> kAny
// TODO(epertoso): consider unifying this with BinaryOperationFeedback.
class CompareOperationFeedback {
public:
@@ -1250,8 +1250,9 @@ class CompareOperationFeedback {
kNone = 0x00,
kSignedSmall = 0x01,
kNumber = 0x3,
- kString = 0x4,
- kAny = 0xf
+ kNumberOrOddball = 0x7,
+ kString = 0x8,
+ kAny = 0x1F
};
};
« no previous file with comments | « no previous file | src/interpreter/interpreter.cc » ('j') | no next file with comments »
@@ -1241,8 +1241,8 @@ class BinaryOperationFeedback {
// at different points by performing an 'OR' operation. Type feedback moves
// to a more generic type when we combine feedback.
-// kSignedSmall -> kNumber -> kAny
-// kString -> kAny
+// kSignedSmall -> kNumber -> kNumberOrOddball -> kAny
+// kString -> kAny
// TODO(epertoso): consider unifying this with BinaryOperationFeedback.
class CompareOperationFeedback {

Powered by Google App Engine
This is Rietveld 408576698